﻿;==========================================================================================================================================================
; Need a unicode aware version of the API directory creator
;==========================================================================================================================================================

Import "shell32.lib"                                                                               ; Import 32 bit shell library
  SHCreateDirectory(*hwnd, pszPath.p-unicode)                                                       ; Grab the function that you want
EndImport                                                                                          ;

;==========================================================================================================================================================
; Try to initialise the sound environment
;==========================================================================================================================================================

If InitSound()  <> 0                                                                                ; Initialise the sound library
  ;Debug "Sound environment okay"
Else                                                                                                ; 
  ;Debug "Sound environment stuffed"
EndIf                                                                                               ; 

;==========================================================================================================================================================
; Use the SQLite database environment for data
;==========================================================================================================================================================

UseSQLiteDatabase()                                                                                 ; Tell compiler we are using SQLite support

;==========================================================================================================================================================
; Print related constants found by Siegfried Rings
;==========================================================================================================================================================

#READYSTATE_UNINITIALIZED       = 0                                                                 ; Print routine with WebGadget
#READYSTATE_LOADING             = 1                                                                 ; 
#READYSTATE_LOADED              = 2                                                                 ; 
#READYSTATE_INTERACTIVE         = 3                                                                 ; 
#READYSTATE_COMPLETE            = 4                                                                 ; 
#OLECMDID_PRINT                 = 6                                                                 ; 
#OLECMDID_PRINTPREVIEW          = 7                                                                 ; 
#OLECMDEXECOPT_DONTPROMPTUSER   = 2                                                                 ; 

;==========================================================================================================================================================
; Get the current postition on a gadget relative to a window
;==========================================================================================================================================================

#LVM_SUBITEMHITTEST             = #LVM_FIRST + 57                                                   ; 

;==========================================================================================================================================================
; Dealing with strikeout attributes on a font in a listicongadget
;==========================================================================================================================================================

#FontStrikeoutYes               = 0                                                                 ; 
#FontStrikeoutNo                = 1                                                                 ; 

;==========================================================================================================================================================
; My personal constants
;==========================================================================================================================================================

#Author                         = "Miklos G Bolvary"                                                ; Author's name
#CopyRight                      = "MGB Technical Services 2014 "                                    ; Copyright holder
#Basename                       = "Appointment Muncher "                                            ; Base name for ini and dataabse
#Version                        = "v1.20b"                                                          ; Program version
#Program                        = #Basename + #Version                                              ; Copyright string
#Fish                           = "<°)))o><²³  "                                                    ; Beware the fish!!

;==========================================================================================================================================================
; Standard program data structure
;==========================================================================================================================================================

Structure ProgramData
  QuitValue.i                                                                                       ; Program quit value
  WindowMutex.i                                                                                     ; Window lock mutex
  LastWindow.s                                                                                      ; The last window opened
  
  CurrentDate.s                                                                                     ; The current date minus the time component
  IsoDate.s                                                                                         ; The current date minus the time component in ISO format
  
  CurrentLine.i                                                                                     ; Currently highlighted line in the list
  CurrentRecord.s                                                                                   ; Currently selected record number
  
  NameColumn.i                                                                                      ; Constants for column positions
  DateColumn.i                                                                                      ; 
  TimeColumn.i                                                                                      ; 
  AlarmColumn.i                                                                                     ; 
  RepeatColumn.i                                                                                    ; 
  ProtectColumn.i                                                                                   ; 
  CategoryColumn.i                                                                                  ; 
  StatusColumn.i                                                                                    ; Column number of deleted record status
  CommentColumn.i                                                                                   ; 
  ArchivedColumn.i                                                                                  ; 
  EmailedColumn.i                                                                                   ; 
  SoundColumn.i                                                                                     ; 
  DeletedColumn.i                                                                                   ; 
  RecordColumn.i                                                                                    ; Column number that the record number is in
  
  AlarmWindowTitle.s                                                                                ; Standard title of the alarm popup screen, gets modified when an alarm is added to it
  
  AlarmNameColumn.i                                                                                 ; Constants for alarm column positions
  AlarmDateColumn.i                                                                                 ; 
  AlarmTimeColumn.i                                                                                 ; 
  AlarmCommentColumn.i                                                                              ; 
  AlarmRecordColumn.i                                                                               ; 
    
  CurrentDirectory.s                                                                                ; Current working directory
  TemporaryDirectory.s                                                                              ; Export, import files and others
  DatabaseDirectory.s                                                                               ; Local database directory
  
  DatabaseName.s                                                                                    ; Local database name
  DatabaseHandle.i                                                                                  ; Opened database handle
  ErrorLogFile.s                                                                                    ; Name of the error log file
  
  SearchCueFont.i                                                                                   ; Searchbox cue font
  SearchNormalFont.i                                                                                ; Searchbox normal font
  SearchCueText.s                                                                                   ; Search box prompt text
  
  OldListIconCallback.i                                                                             ; Coloured header control (Not using)
  BackBrush.i                                                                                       ; Coloured header control
  FrontBrush.i                                                                                      ; Coloured header control
  
  StaticBack.i                                                                                      ; CheckBox, Optiongadget background colours with callback
  
  DontCheck.i                                                                                       ; Do not check dates while another task is running
  
  AppName.s                                                                                         ; 
  AppDate.s                                                                                         ; 
  AppTime.s                                                                                         ; 
  AppAlarm.s                                                                                        ; 
  
  TrayState.i                                                                                       ; Whether program is hidden to tray or not
EndStructure

;==========================================================================================================================================================
; Appointment structure
;==========================================================================================================================================================

Structure AppointmentData                                                                          ; 
  appName.s                                                                                         ; 
  appDate.s                                                                                         ; 
  appTime.s                                                                                         ; 
  appAlarm.s                                                                                        ; 
  appRepeat.s                                                                                       ; 
  appProtect.s                                                                                      ; 
  appCategory.s                                                                                     ; 
  appStatus.s                                                                                       ; 
  appComment.s                                                                                      ; 
  appArchived.s                                                                                     ; 
  appEmailed.s                                                                                      ; 
  appSound.s                                                                                        ; 
  appDeleted.s                                                                                      ; 
  appRecord.s                                                                                       ; 
EndStructure                                                                                       ; 

;==========================================================================================================================================================
; Appointment list icon data
;==========================================================================================================================================================

Structure IconData
  HeaderListIcon.i                                                                                  ; 
  
  ListDeleted.i                                                                                     ; 
  
  CatUnknown.i                                                                                      ; 
  CatAeroplane.i                                                                                    ; 
  CatAmateur.i                                                                                      ; 
  CatAmbulance.i                                                                                    ; 
  CatAnyu.i                                                                                         ; 
  CatBank.i                                                                                         ; 
  CatBus.i                                                                                          ; 
  CatBusiness.i                                                                                     ; 
  CatCamel.i                                                                                        ; 
  CatCbradio.i                                                                                      ; 
  CatCfa.i                                                                                          ; 
  CatCharity.i                                                                                      ; 
  CatDentist.i                                                                                      ; 
  CatDoctor.i                                                                                       ; 
  CatFire.i                                                                                         ; 
  CatFireman.i                                                                                      ; 
  CatHospital.i                                                                                     ; 
  CatMedical.i                                                                                      ; 
  CatOptometrist.i                                                                                  ; 
  CatPersonal.i                                                                                     ; 
  CatPhysiotherapist.i                                                                              ; 
  CatPolice.i                                                                                       ; 
  CatScouts.i                                                                                       ; 
  CatService.i                                                                                      ; 
  CatShopping.i                                                                                     ; 
  CatTaxi.i                                                                                         ; 
  CatTradesman.i                                                                                    ; 
  CatTrain.i                                                                                        ; 
  CatTruck.i                                                                                        ; 
  CatVeterinarian.i                                                                                 ; 
  
  StatusActive.i                                                                                    ; 
  StatusFinished.i                                                                                  ; 
  
  AlarmBlank.i                                                                                      ; 
  AlarmBlue.i                                                                                       ; 
  AlarmGreen.i                                                                                      ; 
  AlarmRed.i                                                                                        ; 
  
  LightNight.i                                                                                      ; 
  LightMorning.i                                                                                    ; 
  LightNoon.i                                                                                       ; 
EndStructure

;==========================================================================================================================================================
; Balloon tooltips with icons structure
;==========================================================================================================================================================

Structure BaloonTipData                                                                            ; 
  handleTip.i                                                                                       ; 
  pbGadgetID.i                                                                                      ; 
  pbGadgetNumber.i                                                                                  ; 
  pbIconHandle.i                                                                                    ; 
EndStructure                                                                                       ; 

;==========================================================================================================================================================
; Setup window variables
;==========================================================================================================================================================

Structure SetupData                                                                                ; 
  TitleClock.i                                                                                      ;   
  StickyWindow.i                                                                                    ; 
  ToolTips.i                                                                                        ;   
  ScreenSnap.i                                                                                      ; 
  AutoArchive.i                                                                                     ; 
  EmailAlarm.i                                                                                      ; 
  
  StartupDates.i                                                                                    ; 
  SnoozePeriod.i                                                                                    ; 
  AlarmSound.i                                                                                      ; 
  LastSearch.s                                                                                      ; 
  
  ServerName.s                                                                                      ; 
  PortNumber.s                                                                                      ; 
  UserName.s                                                                                        ; 
  Password.s                                                                                        ; 
  NeedSsl.s                                                                                         ; 
  EmailAddress.s                                                                                    ; 
EndStructure                                                                                       ; 

;==========================================================================================================================================================
; Error log structure
;==========================================================================================================================================================

Structure ErrorData                                                                                ; 
  ModuleName.s                                                                                      ; 
  ErrorMessage.s                                                                                    ; 
EndStructure                                                                                       ; 

;==========================================================================================================================================================
; Shortcut key code constants. Define once and save a lot of duplication!
;==========================================================================================================================================================

#ShortcutKeys_Add                 = #PB_Shortcut_Alt  | #PB_Shortcut_A                              ; 
#ShortcutKeys_Archive             = #PB_Shortcut_Alt  | #PB_Shortcut_R                              ; 
#ShortcutKeys_Copy                = #PB_Shortcut_Alt  | #PB_Shortcut_C                              ; 
#ShortcutKeys_Delete              = #PB_Shortcut_Alt  | #PB_Shortcut_D                              ; 
#ShortcutKeys_Edit                = #PB_Shortcut_Alt  | #PB_Shortcut_E                              ; 
#ShortcutKeys_Export              = #PB_Shortcut_Alt  | #PB_Shortcut_X                              ; 
#ShortcutKeys_Find                = #PB_Shortcut_Alt  | #PB_Shortcut_F                              ; 
#ShortcutKeys_Help                = #PB_Shortcut_Alt  | #PB_Shortcut_H                              ; 
#ShortcutKeys_Import              = #PB_Shortcut_Alt  | #PB_Shortcut_I                              ; 
#ShortcutKeys_Print               = #PB_Shortcut_Alt  | #PB_Shortcut_P                              ; 
#ShortcutKeys_Show                = #PB_Shortcut_Alt  | #PB_Shortcut_S                              ; 
#ShortcutKeys_Undelete            = #PB_Shortcut_Alt  | #PB_Shortcut_U                              ; 
#ShortcutKeys_Exit                = #PB_Shortcut_Alt  | #PB_Shortcut_X                              ; 

#ShortcutKeys_About               = #PB_Shortcut_F2                                                 ; 
#ShortcutKeys_Shortcuts           = #PB_Shortcut_F3                                                 ; 

#ShortcutKeys_ToolTips            = #PB_Shortcut_F4                                                 ; 
#ShortcutKeys_StickyWindow        = #PB_Shortcut_F5                                                 ; 
#ShortcutKeys_TitleClock          = #PB_Shortcut_F6                                                 ; 
#ShortcutKeys_ScreenSnap          = #PB_Shortcut_F7                                                 ; 
#ShortcutKeys_EmailAlarm          = #PB_Shortcut_F8                                                 ; 
#ShortcutKeys_AutoArchive         = #PB_Shortcut_F9                                                 ; 

#ShortcutKeys_CleanDatabase       = #PB_Shortcut_F10                                                ; 
#ShortcutKeys_Setupprogram        = #PB_Shortcut_F11                                                ; 

#ShortcutKeys_Enter               = #PB_Shortcut_Return                                             ; 

;==========================================================================================================================================================
; Long winded balloon tooltip text for the List of appointments
;==========================================================================================================================================================

#BalloonTextMainHead  = #CRLF$ + #CRLF$ + "List options"                                            ; Line continuation character used below

#BalloonTextMainList  = #CRLF$ + "Single left click (or move the arrow keys"      +
                        #CRLF$ + "up or down) to show the information for the"    + 
                        #CRLF$ + "current appointment details."                   + 
                        #CRLF$ + ""                                               +
                        #CRLF$ + "Double left click to edit the selected"         + 
                        #CRLF$ + "appointment."                                   + 
                        #CRLF$ + ""                                               + 
                        #CRLF$ + "Double right click to add a new appointment"

;==========================================================================================================================================================
; Long winded balloon tooltip text
;==========================================================================================================================================================

#BalloonTextHeadAddAppointment      = "Add an appointment"                                          ; 
#BalloonTextHeadArchiveAppointment  = "Archive an appointment"                                      ; 
#BalloonTextHeadCopyAppointment     = "Copy an appointment"                                         ; 
#BalloonTextHeadDeleteAppointment   = "Delete appointment"                                          ; 
#BalloonTextHeadEditAppointment     = "Edit an appointment"                                         ; 
#BalloonTextHeadExportAppointments  = "Export appointments"                                         ; 
#BalloonTextHeadFindAppointment     = "Find an appointment"                                         ; 
#BalloonTextHeadHelpAppointment     = "Help on appointment"                                         ; 
#BalloonTextHeadImportAppointments  = "Import appointments"                                         ; 
#BalloonTextHeadPrintAppointment    = "Print an appointment"                                        ; 
#BalloonTextHeadShowAppointments    = "Show archived"                                               ; 
#BalloonTextHeadUndeleteAppointment = "Undelete appointment"                                        ; 
#BalloonTextHeadExitAppointment     = "Exit this program"                                           ; 

#BalloonTextHeadAboutAppointments   = "About Program"                                               ; 
#BalloonTextHeadKeyboardShortcuts   = "Keyboard shortcuts"                                          ; 

#BalloonTextHeadToggleTooltips      = "Toggle tooltips"                                             ; 
#BalloonTextHeadToggleStickywindow  = "Toggle stickyWindow"                                         ; 
#BalloonTextHeadToggleTitleClock    = "Toggle titlebar clock"                                       ; 
#BalloonTextHeadToggleScreenSnap    = "Snap program to screen"                                      ; 
#BalloonTextHeadToggleEmailAlarm    = "Toggle email"                                                ; 
#BalloonTextHeadToggleAutoArchive   = "Toggle AutoArchive"                                          ; 

#BalloonTextHeadCleanDatabase       = "Clean deleted entries"                                       ; 
#BalloonTextHeadSetupprogram        = "Setup program options"                                       ; 

;==========================================================================================================================================================
; Long winded balloon tooltip text
;==========================================================================================================================================================

#BalloonTextAddAppointment        = "Add a new appointment to " + #Program                          ; 
#BalloonTextArchiveAppointment    = "Archive an appointment to the archive backup table"            ; 
#BalloonTextCopyAppointment       = "Copy the current appointment to memory"                        ; 
#BalloonTextDeleteAppointment     = "Delete the current appointment from the list"                  ; 
#BalloonTextEditAppointment       = "Edit the current appointment"                                  ; 
#BalloonTextExportAppointments    = "Export appointments to disk"                                   ; 
#BalloonTextFindAppointment       = "Find an appointment in the list"                               ; 
#BalloonTextHelpAppointment       = "Show help pages for " + #Program                               ; 
#BalloonTextImportAppointments    = "Import appointments from disk"                                 ; 
#BalloonTextPrintAppointment      = "Print the current appointment"                                 ; 
#BalloonTextShowAppointments      = "Show archived appointments list"                               ; 
#BalloonTextUndeleteAppointment   = "Undelete the current appointment"                              ; 
#BalloonTextExitAppointment       = "Exit " + #Program + " immediately"                             ; 

#BalloonTextAboutAppointments     = "About " + #Program                                             ; 
#BalloonTextKeyboardShortcuts     = "Show the program assigned keyboard shortcuts"                  ; 

#BalloonTextToggleTooltips        = "Turn the balloon tooltips on or off"                           ; 
#BalloonTextToggleStickywindow    = "Make the windows sit on top or under other windows"            ; 
#BalloonTextToggleTitleClock      = "Turn on the real time clock in the program title bar"          ; 
#BalloonTextToggleScreenSnap      = "Snap AppointmentMuncher to the screen borders"                 ; 
#BalloonTextToggleEmailAlarm      = "Turn the emailing of appointments on or off"                   ; 
#BalloonTextToggleAutoArchive     = "Automatically archive old appointments on or off"              ; 

#BalloonTextCleanDatabase         = "Remove all entries marked deleted, permanently"                ; 
#BalloonTextSetupprogram          = "Setup persistent " + #Program + " program variables"           ; 

;==========================================================================================================================================================
; All literal program strings
;==========================================================================================================================================================

#InfoStringProgramStartup         = #Program + " running, have a nice day"
#InfoStringCannotCopy             = "Cannot copy a deleted appointment, please recover it first. "
#InfoStringFailedCopy             = "Failed to copy any appointments to the system clipboard. "
#InfoStringNoneToCopy             = "No appointments in the list to copy to the clipboard. "
#InfoStringCopyWorked             = " appointments copied to the clipboard. "
#InfoStringNoneToDelete           = "No appointments in the list to be marked as deleted. "
#InfoStringCannotEdit             = "Cannot edit a deleted appointment, please recover it first. "
#InfoStringWindowOpen             = "Another program window is still open, cannot open another one. "
#InfoStringCannotOpen             = "Could not open the requested program window, unknown problem. "
#InfoStringWindowClosed           = "Window closed, resources freed. "
#InfoStringStickyWindow           = "The main program window will now always stay on top of other windows."
#InfoStringNormalWindow           = "The main program window can now be covered by other program windows."
#InfoStringCancelled              = "The currently selected appointment has been cancelled. "
#InfoStringSnoozed                = "The currently selected appointment has been snoozed. "
#InfoStringAlarmRunning           = "The alarm checker is currently running, please wait until it is finished. "
#InfoStringQueryFailed            = "The current database query failed to return any data. "
#InfoStringUpdateFailed           = "The current database update failed to be completed. "
#InfoStringNotSelected            = "The current appointment was skipped for processing as it wasn't selected. "
#InfoStringCannotShow             = "Cannot show information for a deleted appointment. You must recover it first. "
#InfoStringNoRecord               = "Could not get the selected appointment's record number from the list. "
#InfoStringListEmpty              = "There are no appointments in the list to be processed. "
#InfoStringWrongDate              = "Wrong or empty date format for conversion to "
#InfoStringToolTips               = "The main window tooltips are currently turned "
#InfoStringRemovedDeleted         = "All appointments marked as deleted have been permanently removed from the database."
#InfoStringCannotRemove           = "Cannot remove the appointments marked as deleted from the list."
#InfoStringNoneToRemove           = "There no appointments marked deleted in the list to be removed."
#InfoStringNoStringToFind         = "There is nothing to find as the search text field was empty."
#InfoStringTitleBarClock          = "Updating time in window titlebar has been turned "
#InfoStringScreenSnap             = "Snapping program window to screen borders is now "
#InfoStringProtectedItem          = "Cannot clean, delete, view or manage a protected appointment."
#InfoStringNoAlarmComment         = "No comment found for the currently selected alarm."
#InfoStringAlarmExists            = "The selected alarm already exists in the list and will not be added again."
#InfoStringXmlCreateError         = "The main XML data node could not be created, exiting program."
#InfoStringXmlDataSaved           = "The program data has been exported to " + #Program + "_Export.xml"

#InfoStringImportFileDone         = "Finished importing the " + #Program + " XML data file."
#InfoStringImportFileFail         = "Could not load the " + #Program + " XML data file for importing. file or disk error."
#InfoStringImportFileCancel       = "User cancelled the " + #Program + " XML data file import process. Nothing to do."
#InfoStringImportImportLine       = "Current appointment line imported from " + #Program + " export file."
#InfoStringImportImportNoLine     = "Current appointment line not imported from " + #Program + " export file. "

#InfoStringSetupSaveError         = "Program setup data save error. "
#InfoStringSetupSaveOkay          = "Program setup data save okay."

#InfoStringArchiveWorked          = "Appointment copy has been archived."
#InfoStringArchiveFailed          = "Appointment copy failed to be archived."
#InfoStringCannotArchive          = "Cannot archive an appointment marked as deleted."

#InfoStringEmailAlarm             = "Sending alarms by email is now turned "
#InfoStringAutoArchive            = "Automatically archiving old appointments is now "

#InfoStringPopupMenuCreate        = "Popup image menu creation"
#InfoStringPopupMenuCreateError   = "Could not create the popup image menu, program error. Exiting."

#InfoStringBalloonFontErrorHead   = "Balloon tip font error"
#InfoStringBalloonFontErrorText   = "Could not load the balloon tooltip fonts, system error. Exiting"

;==========================================================================================================================================================
; Custom events such as timer numbers
;==========================================================================================================================================================

#Event_Alarm_Check                = 625                                                             ; The number allocated to be checked for alarm events

;==========================================================================================================================================================
; Global constants, including structures
;==========================================================================================================================================================

Global Appointment.AppointmentData                                                                  ; Long form menu text as tooltips
Global Icon.IconData                                                                                ; Listicon icon replacements
Global Program.ProgramData                                                                          ; All my program variables
Global Setup.SetupData                                                                              ; Runtime defaults
Global Balloon.TOOLINFO                                                                             ; Balloon tooltip info structure
Global NewList ErrorString.ErrorData()                                                             ; Module error messages
Global NewList Balloon.BaloonTipData()                                                             ; Balloon tooltip tracking list

;==========================================================================================================================================================
; Srod's coloured ListIconGadget header control (Not used currently)
;==========================================================================================================================================================

; Program\BackBrush  = CreateSolidBrush_($BFBFBF)                                                     ; Coloured header control
; Program\FrontBrush = CreateSolidBrush_($400040)                                                     ; Coloured header control

;==========================================================================================================================================================
; NetMaestro's screen snap code
;==========================================================================================================================================================

Global ScreenW.i, ScreenH.i, SnapD.i = 50, AutoSnap.i = #True                                      ;

SystemParametersInfo_(#SPI_GETWORKAREA, 0, @wa.RECT, 0)                                             ; Client area of the desktop

ScreenW.i = wa\right                                                                                ;

screenH.i = wa\bottom                                                                               ;

;==========================================================================================================================================================
; Setup the search box cue fonts
;==========================================================================================================================================================

Program\SearchCueFont       = LoadFont(#PB_Any,   "Georgia",       13, #PB_Font_Italic)             ; Empty search cue font
Program\SearchNormalFont    = LoadFont(#PB_Any,   "Comic Sans MS", 13, 0)                           ; Filled cue box font
Program\SearchCueText       = Space(256)                                                            ; Set the cue text buffer

PokeS(@Program\SearchCueText, "Search string here...", -1, #PB_Unicode)                             ; Fill the buffer with the cue text

;==========================================================================================================================================================
; Dare and time testing, date display on title bar
;==========================================================================================================================================================

Program\CurrentDate         = FormatDate("%dd/%mm/%yyyy", Date())                                   ; Get the current system date without the time component
Program\IsoDate             = IsoDate(Program\CurrentDate, "IsoDate")                               ; Get the current system date without the time component

;==========================================================================================================================================================
; Used in a callback to colour static controls that PB doesn't manage
;==========================================================================================================================================================

Program\StaticBack          = CreateSolidBrush_($BFBFBF)                                            ; Static controls background colours

;==========================================================================================================================================================
; Setup all directory variables
;==========================================================================================================================================================

Program\CurrentDirectory    = GetCurrentDirectory()                                                 ; Get working directories
Program\DatabaseDirectory   = Program\CurrentDirectory + "Database\"                                ; Set working database directory
Program\TemporaryDirectory  = Program\CurrentDirectory + "Temporary\"                               ; Set temporary files directory

Program\DatabaseName        = Program\DatabaseDirectory + ReplaceString(#Basename, " ", "_") + #Version  +  ".sqlite" ; 
Program\ErrorLogFile        = Program\TemporaryDirectory + #Program + ".Log"                        ; System error log file

;==========================================================================================================================================================
; Create your program directories
;==========================================================================================================================================================

MakeSureDirectoryPathExists(Program\DatabaseDirectory)                                              ; Create the program's working directories if you can 
MakeSureDirectoryPathExists(Program\TemporaryDirectory)                                             ; Set temporary files directory

;==========================================================================================================================================================
; Keep alarm window title as it gets added to
;==========================================================================================================================================================

Program\AlarmWindowTitle    = "Upcoming appointments"                                               ; Standard title of the alarm popup screen, gets modified when an alarm is added to it

;==========================================================================================================================================================
; Main list column titles. They get modified
;==========================================================================================================================================================

Program\AppName             = "_-=Appointment name=-_"                                              ; 
Program\AppDate             = "_-=Date=-_"                                                          ; 
Program\AppTime             = "_-=Time=-_"                                                          ; 
Program\AppAlarm            = "_-=Alarm=-_"                                                         ; 

;==========================================================================================================================================================
; Column numbers on the main appointment list
;==========================================================================================================================================================

Program\NameColumn          =  0                                                                    ; Name column
Program\DateColumn          =  1                                                                    ; 
Program\TimeColumn          =  2                                                                    ; 
Program\AlarmColumn         =  3                                                                    ; Store alarm record number column

Program\RepeatColumn        =  4                                                                    ; 
Program\ProtectColumn       =  5                                                                    ; 
Program\CategoryColumn      =  6                                                                    ; 
Program\StatusColumn        =  7                                                                    ; Store status record number column

Program\CommentColumn       =  8                                                                    ; 
Program\ArchivedColumn      =  9                                                                    ; 
Program\EmailedColumn       = 10                                                                    ; 
Program\SoundColumn         = 11                                                                    ; 

Program\DeletedColumn       = 12                                                                    ; 
Program\RecordColumn        = 13                                                                    ; Store record number column

;==========================================================================================================================================================
; Column numbers on the alarm window list
;==========================================================================================================================================================

Program\AlarmNameColumn     =  0                                                                    ; 
Program\AlarmDateColumn     =  1                                                                    ; 
Program\AlarmTimeColumn     =  2                                                                    ; 
Program\AlarmCommentColumn  =  3                                                                    ; 
Program\AlarmRecordColumn   =  4                                                                    ; 

;==========================================================================================================================================================
; Initial program window quit state
;==========================================================================================================================================================

Program\QuitValue           =  0                                                                    ; Initial program quit value

;==========================================================================================================================================================
; Setup day and month literal names
;==========================================================================================================================================================

Global Dim NameOfDay.s(7)                                                                           ; Fill an array with the names of the days (Terry Hough I think)

   NameOfDay(0)      = "Sunday"
   NameOfDay(1)      = "Monday"
   NameOfDay(2)      = "Tuesday"
   NameOfDay(3)      = "Wednesday"
   NameOfDay(4)      = "Thursday"
   NameOfDay(5)      = "Friday"
   NameOfDay(6)      = "Saturday"

Global Dim DaysPerMonth(12)                                                                         ; Fill an array on how many days per month there are

  For X = 0 To 11     
    DaysPerMonth(X) = 31 
  Next

  DaysPerMonth(1)   = 28
  DaysPerMonth(3)   = 30
  DaysPerMonth(5)   = 30
  DaysPerMonth(8)   = 30
  DaysPerMonth(10)  = 30

Global Dim NameOfMonth.s(12)                                                                        ; Fill an array with the names of the months

  NameOfMonth(0)    = "January"
  NameOfMonth(1)    = "February"
  NameOfMonth(2)    = "March"
  NameOfMonth(3)    = "April"
  NameOfMonth(4)    = "May"
  NameOfMonth(5)    = "June"
  NameOfMonth(6)    = "July"
  NameOfMonth(7)    = "August"
  NameOfMonth(8)    = "September"
  NameOfMonth(9)    = "October"
  NameOfMonth(10)   = "November"
  NameOfMonth(11)   = "December"

Global Dim Years.s(19)                                                                              ; Fill an array with the years

  Years(0)          = "2002"
  Years(1)          = "2003"
  Years(2)          = "2004"
  Years(3)          = "2005"
  Years(4)          = "2006" 
  Years(5)          = "2007"
  Years(6)          = "2008"
  Years(7)          = "2009"
  Years(8)          = "2010"
  Years(9)          = "2011"
  Years(10)         = "2012"
  Years(11)         = "2013"
  Years(12)         = "2014"
  Years(13)         = "2015"
  Years(14)         = "2016"
  Years(15)         = "2017"
  Years(16)         = "2018"
  Years(17)         = "2019"
  Years(18)         = "2020"
  
;==========================================================================================================================================================
; Extra gadget and menu constants
;==========================================================================================================================================================

Enumeration #GadgetIndex                                                                           ; Follow on from visual designer created constants
  #Systray_AppointmentMuncher_Tray                                                                  ; 
  
  #Menu_AppointmentMuncher
  #Menu_Add                                                                                         ; 
  #Menu_Archive                                                                                     ; 
  #Menu_Copy                                                                                        ; 
  #Menu_Delete                                                                                      ; 
  #Menu_Edit                                                                                        ; 
  #Menu_Export                                                                                      ; 
  #Menu_Find                                                                                        ; 
  #Menu_Help                                                                                        ; 
  #Menu_Import                                                                                      ; 
  #Menu_Print                                                                                       ; 
  #Menu_Show                                                                                        ; 
  #Menu_Undelete                                                                                    ; 
  #Menu_Exit                                                                                        ; 
  
  #Menu_About                                                                                       ; 
  #Menu_Shortcuts                                                                                   ; 
  
  #Menu_Tooltips                                                                                    ; 
  #Menu_Stickywindow                                                                                ; 
  #Menu_Titleclock                                                                                  ; 
  #Menu_Screensnap                                                                                  ; 
  #Menu_EmailAlarm                                                                                  ; 
  #Menu_AutoArchive                                                                                 ; 
  
  #Menu_Cleandatabase                                                                               ; 
  #Menu_Setupprogram                                                                                ; 

  #Shortcut_Add                                                                                     ; 
  #Shortcut_Archive                                                                                 ; 
  #Shortcut_Copy                                                                                    ; 
  #Shortcut_Delete                                                                                  ; 
  #Shortcut_Edit                                                                                    ; 
  #Shortcut_Export                                                                                  ; 
  #Shortcut_Find                                                                                    ; 
  #Shortcut_Help                                                                                    ; 
  #Shortcut_Import                                                                                  ; 
  #Shortcut_Print                                                                                   ; 
  #Shortcut_Show                                                                                    ; 
  #Shortcut_Undelete                                                                                ; 
  #Shortcut_Exit                                                                                    ; 
  
  #Shortcut_About                                                                                   ; 
  #Shortcut_Shortcuts                                                                               ; 
  
  #Shortcut_Tooltips                                                                                ; 
  #Shortcut_Stickywindow                                                                            ; 
  #Shortcut_Titleclock                                                                              ; 
  #Shortcut_ScreenSnap                                                                              ; 
  #Shortcut_EmailAlarm                                                                              ; 
  #Shortcut_AutoArchive                                                                             ; 
  
  #Shortcut_Cleandatabase                                                                           ; 
  #Shortcut_Setupprogram                                                                            ; 
  
  #Shortcut_Enter                                                                                 ; 
  
  #Shortcut_AppointmentAbout_Escape                                                                 ; 
  #Shortcut_AppointmentAlarm_Escape                                                                 ; 
  #Shortcut_AppointmentData_Escape                                                                  ; 
  #Shortcut_AppointmentFind_Escape                                                                  ; 
  #Shortcut_AppointmentFind_Enter                                                                   ; 
  #Shortcut_AppointmentSetup_Escape                                                                 ; 
  #Shortcut_AppointmentKeys_Escape                                                                  ; 
  #Shortcut_AppointmentHelp_Escape                                                                  ; 
  #Shortcut_AppointmentArchive_Escape                                                               ; 
  #Shortcut_AppointmentArchive_Enter                                                                ; 
EndEnumeration

;==========================================================================================================================================================
; Extra image constants
;==========================================================================================================================================================

Enumeration #ImageIndex                                                                            ; Follow on from visual designer created constants
  #ProgramIcon                                                                                      ; 
  
  #ListTooltip                                                                                      ; List tooltip button
  
  #Image_Archive_N                                                                                  ; 
  #Image_Show_N                                                                                     ; 
  
  #Image_Add_H                                                                                      ; 
  #Image_Archive_H                                                                                  ; 
  #Image_Cancel_H                                                                                   ; 
  #Image_Clean_H                                                                                    ; 
  #Image_Copy_H                                                                                     ; 
  #Image_Delete_H                                                                                   ; 
  #Image_Edit_H                                                                                     ; 
  #Image_Export_H                                                                                   ; 
  #Image_Find_H                                                                                     ; 
  #Image_Help_H                                                                                     ;   
  #Image_Import_H                                                                                   ; 
  #Image_Print_H                                                                                    ; 
  #Image_Restore_H                                                                                  ; 
  #Image_Save_H                                                                                     ; 
  #Image_Setup_H                                                                                    ; 
  #Image_Snooze_H                                                                                   ; 
  #Image_Show_H                                                                                     ; 
  #Image_StopSound_H                                                                                ; 
  #Image_Undelete_H                                                                                 ; 
  #Image_Tooltips_H                                                                                 ;   
  #Image_Stickywindow_H                                                                             ;   
  #Image_Titleclock_H                                                                               ;   
  #Image_Exit_H                                                                                     ; 
  
  #Image_Add_P                                                                                      ; 
  #Image_Archive_P                                                                                  ; 
  #Image_Cancel_P                                                                                   ; 
  #Image_Clean_P                                                                                    ; 
  #Image_Copy_P                                                                                     ; 
  #Image_Delete_P                                                                                   ; 
  #Image_Edit_P                                                                                     ; 
  #Image_Export_P                                                                                   ; 
  #Image_Find_P                                                                                     ; 
  #Image_Help_P                                                                                     ;   
  #Image_Import_P                                                                                   ; 
  #Image_Print_P                                                                                    ; 
  #Image_Restore_P                                                                                  ; 
  #Image_Save_P                                                                                     ; 
  #Image_Setup_P                                                                                    ; 
  #Image_Snooze_P                                                                                   ; 
  #Image_Show_P                                                                                     ; 
  #Image_StopSound_P                                                                                ; 
  #Image_Undelete_P                                                                                 ; 
  #Image_Tooltips_P                                                                                 ; 
  #Image_Stickywindow_P                                                                             ; 
  #Image_Titleclock_P                                                                               ;   
  #Image_Exit_P                                                                                     ; 
  
  #Image_iAbout_H                                                                                   ; 
  #Image_iAbout_P                                                                                   ; 
  
  #Image_iShortcuts_H                                                                               ; 
  #Image_iShortcuts_P                                                                               ; 
  
  #ListDeleted                                                                                      ; 
  
  #CatUnknown                                                                                       ; 
  #CatAeroplane                                                                                     ; 
  #CatAmateur                                                                                       ; 
  #CatAmbulance                                                                                     ; 
  #CatAnyu                                                                                          ; 
  #CatBank                                                                                          ; 
  #CatBus                                                                                           ; 
  #CatBusiness                                                                                      ; 
  #CatCamel                                                                                         ; 
  #CatCbradio                                                                                       ; 
  #CatCfa                                                                                           ; 
  #CatCharity                                                                                       ; 
  #CatDentist                                                                                       ; 
  #CatDoctor                                                                                        ; 
  #CatFire                                                                                          ; 
  #CatFireman                                                                                       ; 
  #CatHospital                                                                                      ; 
  #CatMedical                                                                                       ; 
  #CatOptometrist                                                                                   ; 
  #CatPersonal                                                                                      ; 
  #CatPhysiotherapist                                                                               ; 
  #CatPolice                                                                                        ; 
  #CatScouts                                                                                        ; 
  #CatService                                                                                       ; 
  #CatShopping                                                                                      ; 
  #CatTaxi                                                                                          ; 
  #CatTradesman                                                                                     ; 
  #CatTrain                                                                                         ; 
  #CatTruck                                                                                         ; 
  #CatVeterinarian                                                                                  ; 
  
  #StatusActive                                                                                     ; 
  #StatusFinished                                                                                   ; 
  
  #AlarmBlank                                                                                       ; No alarm, keeps column justified
  #AlarmBlue                                                                                        ; Alarm is in the future
  #AlarmGreen                                                                                       ; Alarm is today
  #AlarmRed                                                                                         ; Alarm is in the past
  
  #LightNight                                                                                       ; 
  #LightMorning                                                                                     ; 
  #LightNoon                                                                                        ; 
  
  #SnoozeClock                                                                                      ; 
  
  #SearchType                                                                                       ; 
  #SearchField                                                                                      ; 
  
  #Alarmsound                                                                                       ; 
  #Clipboard                                                                                        ; 
  #Repeatalarm                                                                                      ; 
  #Shortcuts                                                                                        ; 
  
  #Locked                                                                                           ; 
  #Unlocked                                                                                         ; 
EndEnumeration

;==========================================================================================================================================================
; 
;==========================================================================================================================================================

Enumeration                                                                                        ; 
  #SndStandard                                                                                      ; 
EndEnumeration                                                                                     ; 

;==========================================================================================================================================================
; Load images into memory from the datasection references
;==========================================================================================================================================================

CatchImage(#ProgramIcon,           ?_ProgramIcon)                                                   ; 
CatchImage(#ListTooltip,           ?_ListTooltip)                                                   ; List tooltip button

CatchImage(#Image_Archive_N,       ?_Image_Archive_N)                                               ; 
CatchImage(#Image_Show_N,          ?_Image_Show_N)                                                  ; 

CatchImage(#Image_Add_H,           ?_Image_Add_H)                                                   ; 
CatchImage(#Image_Archive_H,       ?_Image_Archive_H)                                               ; 
CatchImage(#Image_Cancel_H,        ?_Image_Cancel_H)                                                ; 
CatchImage(#Image_Clean_H,         ?_Image_Clean_H)                                                 ; Normal images that don't have buttons
CatchImage(#Image_Copy_H,          ?_Image_Copy_H)                                                  ; 
CatchImage(#Image_Delete_H,        ?_Image_Delete_H)                                                ; 
CatchImage(#Image_Edit_H,          ?_Image_Edit_H)                                                  ; 
CatchImage(#Image_Export_H,        ?_Image_Export_H)                                                ; Normal images that don't have buttons
CatchImage(#Image_Find_H,          ?_Image_Find_H)            ; 
CatchImage(#Image_Help_H,          ?_Image_Help_H)            ; 
CatchImage(#Image_Import_H,        ?_Image_Import_H)          ; 
CatchImage(#Image_Print_H,         ?_Image_Print_H)           ; 
CatchImage(#Image_Restore_H,       ?_Image_Restore_H)         ; 
CatchImage(#Image_Save_H,          ?_Image_Save_H)            ; 
CatchImage(#Image_Setup_H,         ?_Image_Setup_H)           ; 
CatchImage(#Image_Snooze_H,        ?_Image_Snooze_H)          ; 
CatchImage(#Image_Show_H,          ?_Image_Show_H)            ;
CatchImage(#Image_StopSound_H,     ?_Image_StopSound_H)       ; 
CatchImage(#Image_Undelete_H,      ?_Image_Undelete_H)        ; 
CatchImage(#Image_Tooltips_H,      ?_Image_Tooltips_H)        ; 
CatchImage(#Image_Stickywindow_H,  ?_Image_Stickywindow_H)    ; 
CatchImage(#Image_Titleclock_H,    ?_Image_Titleclock_H)      ; 
CatchImage(#Image_Exit_H,          ?_Image_Exit_H)            ; 

CatchImage(#Image_Add_P,           ?_Image_Add_P)             ; 
CatchImage(#Image_Archive_P,       ?_Image_Archive_P)         ; 
CatchImage(#Image_Cancel_P,        ?_Image_Cancel_P)          ; 
CatchImage(#Image_Clean_P,         ?_Image_Clean_P)           ; Normal images that don't have buttons
CatchImage(#Image_Copy_P,          ?_Image_Copy_P)            ; 
CatchImage(#Image_Delete_P,        ?_Image_Delete_P)          ; 
CatchImage(#Image_Edit_P,          ?_Image_Edit_P)            ; 
CatchImage(#Image_Export_P,        ?_Image_Export_P)          ; Normal images that don't have buttons
CatchImage(#Image_Find_P,          ?_Image_Find_P)            ; 
CatchImage(#Image_Help_P,          ?_Image_Help_P)            ; 
CatchImage(#Image_Import_P,        ?_Image_Import_P)          ; 
CatchImage(#Image_Print_P,         ?_Image_Print_P)           ; 
CatchImage(#Image_Restore_P,       ?_Image_Restore_P)         ; 
CatchImage(#Image_Save_P,          ?_Image_Save_P)            ; 
CatchImage(#Image_Setup_P,         ?_Image_Setup_P)           ; 
CatchImage(#Image_Snooze_P,        ?_Image_Snooze_P)          ; 
CatchImage(#Image_Show_P,          ?_Image_Show_P)            ;
CatchImage(#Image_StopSound_P,     ?_Image_StopSound_P)       ; 
CatchImage(#Image_Undelete_P,      ?_Image_Undelete_P)        ; 
CatchImage(#Image_Tooltips_P,      ?_Image_Tooltips_P)        ; 
CatchImage(#Image_Stickywindow_P,                       ?_Image_Stickywindow_P)    ; 
CatchImage(#Image_Titleclock_P,    ?_Image_Titleclock_P)      ; 
CatchImage(#Image_Exit_P,                             ?_Image_Exit_P)            ; 

CatchImage(#Image_iAbout_H,                           ?_Image_iAbout_H)          ; 
CatchImage(#Image_iAbout_P,                           ?_Image_iAbout_P)          ; 

CatchImage(#Image_iShortcuts_H,                       ?_Image_iShortcuts_H)      ; 
CatchImage(#Image_iShortcuts_P,                       ?_Image_iShortcuts_P)      ; 
  
CatchImage(#ListDeleted,                              ?_ListDeleted)                                ; Main list icon if none other used

CatchImage(#CatUnknown,                               ?_CatUnknown)                                 ; 
CatchImage(#CatAeroplane,                             ?_CatAeroplane)                               ; 
CatchImage(#CatAmateur,                               ?_CatAmateur)                                 ; 
CatchImage(#CatAmbulance,                             ?_CatAmbulance)                               ; 
CatchImage(#CatAnyu,                                  ?_CatAnyu)                                    ; 
CatchImage(#CatBank,                                  ?_CatBank)                                    ; 
CatchImage(#CatBus,                                   ?_CatBus)                                     ; 
CatchImage(#CatBusiness,                              ?_CatBusiness)                                ; 
CatchImage(#CatCamel,                                 ?_CatCamel)                                   ; 
CatchImage(#CatCbradio,                               ?_CatCbradio)                                 ; 
CatchImage(#CatCfa,                                   ?_CatCfa)                                     ; 
CatchImage(#CatCharity,                               ?_CatCharity)                                 ; 
CatchImage(#CatDentist,                               ?_CatDentist)                                 ; 
CatchImage(#CatDoctor,                                ?_CatDoctor)                                  ; 
CatchImage(#CatFire,                                  ?_CatFire)                                    ; 
CatchImage(#CatFireman,                               ?_CatFireman)                                 ; 
CatchImage(#CatHospital,                              ?_CatHospital)                                ; 
CatchImage(#CatMedical,                               ?_CatMedical)                                 ; 
CatchImage(#CatOptometrist,                           ?_CatOptometrist)                             ; 
CatchImage(#CatPersonal,                              ?_CatPersonal)                                ; 
CatchImage(#CatPhysiotherapist,                       ?_CatPhysiotherapist)                         ; 
CatchImage(#CatPolice,                                ?_CatPolice)                                  ; 
CatchImage(#CatScouts,                                ?_CatScouts)                                  ; 
CatchImage(#CatService,                               ?_CatService)                                 ; 
CatchImage(#CatShopping,                              ?_CatShopping)                                ; 
CatchImage(#CatTaxi,                                  ?_CatTaxi)                                    ; 
CatchImage(#CatTradesman,                             ?_CatTradesman)                               ; 
CatchImage(#CatTrain,                                 ?_CatTrain)                                   ; 
CatchImage(#CatTruck,                                 ?_CatTruck)                                   ; 
CatchImage(#CatVeterinarian,                          ?_CatVeterinarian)                            ; 

CatchImage(#StatusActive,                             ?_StatusActive)                               ; 
CatchImage(#StatusFinished,                           ?_StatusFinished)                             ; 

CatchImage(#AlarmBlank,                               ?_AlarmBlank)                                 ; No alarm, keeps column justified
CatchImage(#AlarmBlue,                                ?_AlarmBlue)                                  ; Alarm is in the future
CatchImage(#AlarmGreen,                               ?_AlarmGreen)                                 ; Alarm is today
CatchImage(#AlarmRed,                                 ?_AlarmRed)                                   ; Alarm is in the past

CatchImage(#LightNight,                               ?_LightNight)                                 ; 
CatchImage(#LightMorning,                             ?_LightMorning)                               ; 
CatchImage(#LightNoon,                                ?_LightNoon)                                  ; 

CatchImage(#SnoozeClock,                              ?_SnoozeClock)                                ; 

CatchImage(#SearchType,                               ?_SearchType)                                 ; 
CatchImage(#SearchField,                              ?_SearchField)                                ; 

CatchImage(#Alarmsound,                               ?_Alarmsound)                                 ; 
CatchImage(#Clipboard,                                ?_Clipboard)                                  ; 
CatchImage(#Repeatalarm,                              ?_Repeatalarm)                                ; 
CatchImage(#Shortcuts,                                ?_Shortcuts)                                  ; 

CatchImage(#Locked,                                   ?_Locked)                                     ; 
CatchImage(#Unlocked,                                 ?_Unlocked)                                   ; 

;==========================================================================================================================================================
; Datasection references
;==========================================================================================================================================================

CatchSound(#SndStandard,                              ?_SndStandard)                                ; 

;==========================================================================================================================================================
; Datasection references
;==========================================================================================================================================================

DataSection
  
  ; Text files
  
  _AppointmentMuncher_About:                      : IncludeBinary "Helpfiles\AboutAppointmentMuncher.rtf"          ; 
  
  _AppointmentMuncher_Help:                       : IncludeBinary "Helpfiles\HelpAppointmentMuncher.rtf"           ; 
  
  ; Images of all sorts
  
  _ProgramIcon:                                   : IncludeBinary  "Images\General\Program.ico"          ; 
  
  _ListTooltip:                                   : IncludeBinary  "Images\General\ListTooltip.ico"      ; List tooltip button:
  
  _Image_Archive_N:            : IncludeBinary  "Images\Buttons\Archive-n.png"        ; 
  _Image_Show_N:               : IncludeBinary  "Images\Buttons\Show-n.png"           ; 

  _Image_Add_H:                : IncludeBinary  "Images\Buttons\Add-h.png"            ; 
  _Image_Archive_H:            : IncludeBinary  "Images\Buttons\Archive-h.png"        ; 
  _Image_Cancel_H:             : IncludeBinary  "Images\Buttons\Cancel-h.png"         ; 
  _Image_Clean_H:              : IncludeBinary  "Images\Buttons\Clean-h.png"          ; 
  _Image_Copy_H:               : IncludeBinary  "Images\Buttons\Copy-h.png"           ; 
  _Image_Delete_H:             : IncludeBinary  "Images\Buttons\Delete-h.png"         ; 
  _Image_Edit_H:               : IncludeBinary  "Images\Buttons\Edit-h.png"           ; 
  _Image_Export_H:             : IncludeBinary  "Images\Buttons\Export-h.png"         ; 
  _Image_Find_H:               : IncludeBinary  "Images\Buttons\Find-h.png"           ; 
  _Image_Help_H:               : IncludeBinary  "Images\Buttons\Help-h.png"           ; 
  _Image_Import_H:             : IncludeBinary  "Images\Buttons\Import-h.png"         ; 
  _Image_Print_H:              : IncludeBinary  "Images\Buttons\Print-h.png"          ; 
  _Image_Restore_H:            : IncludeBinary  "Images\Buttons\Restore-h.png"        ; 
  _Image_Save_H:               : IncludeBinary  "Images\Buttons\Save-h.png"           ; 
  _Image_Setup_H:              : IncludeBinary  "Images\Buttons\Setup-h.png"          ; 
  _Image_Snooze_H:             : IncludeBinary  "Images\Buttons\Snooze-h.png"         ; 
  _Image_Show_H:               : IncludeBinary  "Images\Buttons\Show-h.png"           ; 
  _Image_StopSound_H:          : IncludeBinary  "Images\Buttons\StopSound-h.png"       ; 
  _Image_Undelete_H:           : IncludeBinary  "Images\Buttons\Undelete-h.png"       ; 
  _Image_Tooltips_H:           : IncludeBinary  "Images\Buttons\Tooltips-h.png"       ; 
  _Image_Stickywindow_H:       : IncludeBinary  "Images\Buttons\Stickywindow-h.png"   ; 
  _Image_Titleclock_H:         : IncludeBinary  "Images\Buttons\Clock-h.png"          ; 
  _Image_Exit_H:               : IncludeBinary  "Images\Buttons\Exit-h.png"           ; 
  
  _Image_Add_P:                : IncludeBinary  "Images\Buttons\Add-p.png"            ; 
  _Image_Archive_P:            : IncludeBinary  "Images\Buttons\Archive-p.png"        ; 
  _Image_Cancel_P:             : IncludeBinary  "Images\Buttons\Cancel-p.png"         ; 
  _Image_Clean_P:              : IncludeBinary  "Images\Buttons\Clean-p.png"          ; 
  _Image_Copy_P:               : IncludeBinary  "Images\Buttons\Copy-p.png"           ; 
  _Image_Delete_P:             : IncludeBinary  "Images\Buttons\Delete-p.png"         ; 
  _Image_Edit_P:               : IncludeBinary  "Images\Buttons\Edit-p.png"           ; 
  _Image_Export_P:             : IncludeBinary  "Images\Buttons\Export-p.png"         ; 
  _Image_Find_P:               : IncludeBinary  "Images\Buttons\Find-p.png"           ; 
  _Image_Help_P:               : IncludeBinary  "Images\Buttons\Help-p.png"           ; 
  _Image_Import_P:             : IncludeBinary  "Images\Buttons\Import-p.png"         ; 
  _Image_Print_P:              : IncludeBinary  "Images\Buttons\Print-p.png"          ; 
  _Image_Restore_P:            : IncludeBinary  "Images\Buttons\Restore-p.png"        ; 
  _Image_Save_P:               : IncludeBinary  "Images\Buttons\Save-p.png"           ; 
  _Image_Setup_P:              : IncludeBinary  "Images\Buttons\Setup-p.png"          ; 
  _Image_Snooze_P:             : IncludeBinary  "Images\Buttons\Snooze-p.png"         ; 
  _Image_Show_P:               : IncludeBinary  "Images\Buttons\Show-p.png"           ; 
  _Image_StopSound_P:          : IncludeBinary  "Images\Buttons\StopSound-p.png"      ; 
  _Image_Undelete_P:           : IncludeBinary  "Images\Buttons\Undelete-p.png"       ; 
  _Image_Tooltips_P:           : IncludeBinary  "Images\Buttons\Tooltips-p.png"       ; 
  _Image_Stickywindow_P:       : IncludeBinary  "Images\Buttons\Stickywindow-p.png"   ; 
  _Image_Titleclock_P:         : IncludeBinary  "Images\Buttons\Clock-p.png"          ; 
  _Image_Exit_P:               : IncludeBinary  "Images\Buttons\Exit-p.png"           ; 
  
  _Image_iAbout_H:             : IncludeBinary  "Images\General\About-h.png"          ; 
  _Image_iAbout_P:             : IncludeBinary  "Images\General\About-p.png"          ; 

  _Image_iShortcuts_H:         : IncludeBinary  "Images\General\Shortcuts-h.png"      ; 
  _Image_iShortcuts_P:         : IncludeBinary  "Images\General\Shortcuts-p.png"      ; 

  _ListDeleted:                                   : IncludeBinary  "Images\List\Deleted.ico"             ; Main list icon if none other used
  
  _CatUnknown:                                    : IncludeBinary  "Images\Category\Unknown.ico"         ; 
  _CatAeroplane:                                  : IncludeBinary  "Images\Category\Aeroplane.ico"       ; 
  _CatAmateur:                                    : IncludeBinary  "Images\Category\Amateur.ico"         ; 
  _CatAmbulance:                                  : IncludeBinary  "Images\Category\Ambulance.ico"       ; 
  _CatAnyu:                                       : IncludeBinary  "Images\Category\Anyu.ico"            ; 
  _CatBank:                                       : IncludeBinary  "Images\Category\Bank.ico"            ; 
  _CatBus:                                        : IncludeBinary  "Images\Category\Bus.ico"             ; 
  _CatBusiness:                                   : IncludeBinary  "Images\Category\Business.ico"        ; 
  _CatCamel:                                      : IncludeBinary  "Images\Category\Camel.ico"           ; 
  _CatCbradio:                                    : IncludeBinary  "Images\Category\Cbradio.ico"         ; 
  _CatCfa:                                        : IncludeBinary  "Images\Category\Cfa.ico"             ; 
  _CatCharity:                                    : IncludeBinary  "Images\Category\Charity.ico"         ; 
  _CatDentist:                                    : IncludeBinary  "Images\Category\Dentist.ico"         ; 
  _CatDoctor:                                     : IncludeBinary  "Images\Category\Doctor.ico"          ; 
  _CatFire:                                       : IncludeBinary  "Images\Category\Fire.ico"            ; 
  _CatFireman:                                    : IncludeBinary  "Images\Category\Fireman.ico"         ; 
  _CatHospital:                                   : IncludeBinary  "Images\Category\Hospital.ico"        ; 
  _CatMedical:                                    : IncludeBinary  "Images\Category\Medical.ico"         ; 
  _CatOptometrist:                                : IncludeBinary  "Images\Category\Optometrist.ico"     ; 
  _CatPersonal:                                   : IncludeBinary  "Images\Category\Personal.ico"        ; 
  _CatPhysiotherapist:                            : IncludeBinary  "Images\Category\Physiotherapist.ico" ; 
  _CatPolice:                                     : IncludeBinary  "Images\Category\Police.ico"          ; 
  _CatScouts:                                     : IncludeBinary  "Images\Category\Scouts.ico"          ; 
  _CatService:                                    : IncludeBinary  "Images\Category\Service.ico"         ; 
  _CatShopping:                                   : IncludeBinary  "Images\Category\Shopping.ico"        ; 
  _CatTaxi:                                       : IncludeBinary  "Images\Category\Taxi.ico"            ; 
  _CatTradesman:                                  : IncludeBinary  "Images\Category\Tradesman.ico"       ; 
  _CatTrain:                                      : IncludeBinary  "Images\Category\Train.ico"           ; 
  _CatTruck:                                      : IncludeBinary  "Images\Category\Truck.ico"           ;   
  _CatVeterinarian:                               : IncludeBinary  "Images\Category\Veterinarian.ico"    ;   
  
  _StatusActive:                                  : IncludeBinary  "Images\Status\Active.ico"            ; 
  _StatusFinished:                                : IncludeBinary  "Images\Status\Finished.ico"          ; 

  _AlarmBlank:                                    : IncludeBinary  "Images\Alarms\AlarmBlank16x16.ico"   ; No alarm, keeps column justified
  _AlarmBlue:                                     : IncludeBinary  "Images\Alarms\AlarmBlue16x16.ico"    ; Alarm is in the future
  _AlarmGreen:                                    : IncludeBinary  "Images\Alarms\AlarmGreen16x16.ico"   ; Alarm is today
  _AlarmRed:                                      : IncludeBinary  "Images\Alarms\AlarmRed16x16.ico"     ; Alarm is in the past
  
  _LightNight:                                    : IncludeBinary  "Images\Timeofday\Night.ico"          ; 
  _LightMorning:                                  : IncludeBinary  "Images\Timeofday\Morning.ico"        ; 
  _LightNoon:                                     : IncludeBinary  "Images\Timeofday\Afternoon.ico"      ; 
  
  _SnoozeClock:                                   : IncludeBinary  "Images\General\Snooze.ico"           ;  
  
  _SearchType:                                    : IncludeBinary  "Images\General\Sql.ico"              ; 
  _SearchField:                                   : IncludeBinary  "Images\General\Field.ico"            ; 
  
  _Alarmsound:                                    : IncludeBinary  "Images\General\AlarmSound.ico"       ; 
  _Clipboard:                                     : IncludeBinary  "Images\General\Clipboard.ico"        ; 
  _Repeatalarm:                                   : IncludeBinary  "Images\General\RepeatAlarm.ico"      ;  
  _Shortcuts:                                     : IncludeBinary  "Images\General\Shortcuts.ico"        ; 
  
  _Locked:                                        : IncludeBinary  "Images\General\Locked.ico"           ; 
  _Unlocked:                                      : IncludeBinary  "Images\General\Unlocked.ico"         ; 

  ; Sound files
  
  _SndStandard:                                   : IncludeBinary  "Sounds\StandardSound.wav"            ; 
  
  ; Combobox data
  
  BeginCategories:
  
  Data.s  "Unknown",           "0"
  Data.s  "Aeroplane",         "1"
  Data.s  "Amateur",           "2"
  Data.s  "Ambulance",         "3"
  Data.s  "Anyu",              "4"
  Data.s  "Bank",              "5"
  Data.s  "Bus",               "6"
  Data.s  "Business",          "7"
  Data.s  "Camel",             "8"
  Data.s  "Cbradio",           "9"
  Data.s  "Cfa",              "10"
  Data.s  "Charity",          "11"
  Data.s  "Dentist",          "12"
  Data.s  "Doctor",           "13"
  Data.s  "Fire",             "14"
  Data.s  "Fireman",          "15"
  Data.s  "Hospital",         "16"
  Data.s  "Medical",          "17"
  Data.s  "Optometrist",      "18"
  Data.s  "Personal",         "19"
  Data.s  "Physiotherapist",  "20"
  Data.s  "Police",           "21"
  Data.s  "Scouts",           "22"
  Data.s  "Service",          "23"
  Data.s  "Shopping",         "24"
  Data.s  "Taxi",             "25"
  Data.s  "Tradesman",        "26"
  Data.s  "Train",            "27"
  Data.s  "Truck",            "28"
  Data.s  "Veterinarian",     "29"
  Data.s  "_EndCategories_",  "00"
  
  BeginSnoozeSettings:
  
  Data.s  "Alarm Off"
  Data.s  " 5 Min"
  Data.s  "10 Min"
  Data.s  "15 Min"
  Data.s  "20 Min"
  Data.s  "30 Min"
  Data.s  "40 Min"
  Data.s  "50 Min"
  Data.s  " 1 Hr"
  Data.s  " 2 Hrs"
  Data.s  " 3 Hrs"
  Data.s  " 4 Hrs"
  Data.s  " 5 Hrs"
  Data.s  " 6 Hrs"
  Data.s  " 7 Hrs"
  Data.s  " 8 Hrs"
  Data.s  "_EndSnoozeSettings_"
  
  SearchTypes:
  
  Data.s  "Sounds like"
  Data.s  "Equal to"
  Data.s  "Does not equal"
  Data.s  "Greater than"
  Data.s  "Greater than or equal to"
  Data.s  "Less than"
  Data.s  "Less than or equal to"
  Data.s  "Starts with"
  Data.s  "Ends with"
  Data.s  "_EndSearchTypes_"
  
  SearchFields:
  
  Data.s  "Appointment name"
  Data.s  "Date to execute"
  Data.s  "Time of day"
  Data.s  "Alarm Set"
  Data.s  "Recurring date"
  Data.s  "Protected item"
  Data.s  "Category type"
  Data.s  "Status of appointment"
  Data.s  "Extra comments"
  Data.s  "Archived copy"
  Data.s  "Appointment emailed"
  Data.s  "Sound file for alarm"
  Data.s  "Marked deleted or not"
  Data.s  "Record number"
  Data.s  "_EndSearchFields_"
  
  StartupDates:
  
  Data.s  "All events"
  Data.s  "Active events"
  Data.s  "Past events"
  Data.s  "Today's events"
  Data.s  "Future events"
  Data.s  "Finished events"
  Data.s  "Deleted events"
  Data.s  "_EndStartupDates_"
  
  AlarmSounds:
  
  Data.s  "No sounds"
  Data.s  "Standard sound"
  Data.s  "_EndAlarmSounds_"
  
  AlarmRepeats:
  
  Data.s  "No repeat"
  Data.s  "Hourly"
  Data.s  "Daily"
  Data.s  "Weekly"
  Data.s  "Montly"
  Data.s  "Yearly"
  Data.s  "_EndAlarmRepeats_"
  
EndDataSection


; IDE Options = PureBasic 5.23 LTS (Windows - x86)
; CursorPosition = 874
; FirstLine = 856
; EnableXP
; HideErrorLog