﻿;==========================================================================================================================================================
; Load the list of archived appointments
;==========================================================================================================================================================

Procedure ShowArchivedAppointments()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if the alarm checker is running first
  ;------------------------------------------------------------------------------------------------
  
  If Program\DontCheck <> 1
    
    ;----------------------------------------------------------------------------------------------
    ; Check if a previous window is open
    ;----------------------------------------------------------------------------------------------
    
    If Program\WindowMutex <> 1
      
      ;--------------------------------------------------------------------------------------------
      ; Try to open the Archive window
      ;--------------------------------------------------------------------------------------------
      
      If Window_AppointmentArchive()
        
        ;------------------------------------------------------------------------------------------
        ; Set the new imagelist to the gadget
        ;------------------------------------------------------------------------------------------
        
        BuildImageList(#Gadget_AppointmentArchive_Appointments)
        
        ;------------------------------------------------------------------------------------------
        ; Remove the borders from some gadgets that don't have pb comands to do so. This makes the 'flat'
        ; look more consistent.
        ;------------------------------------------------------------------------------------------
        
        RemoveBorders(#Gadget_AppointmentArchive_Appointments)
        
        ;------------------------------------------------------------------------------------------
        ; Remove theme support for certain gadgets where colours don't seem to work in PureBasic. This is
        ; as there is no crossplatform colour support for these controls
        ;------------------------------------------------------------------------------------------
        
        SetWindowTheme_(GadgetID(#Gadget_AppointmentArchive_Comment),       @null.w, @null.w)

        ;------------------------------------------------------------------------------------------
        ; Prevent user input on the main window
        ;------------------------------------------------------------------------------------------
        
        DisableWindow(#Window_AppointmentMuncher, #True)
        
        ;------------------------------------------------------------------------------------------
        ; Warn other components a window is open and not to attempt to open another
        ;------------------------------------------------------------------------------------------
        
        Program\WindowMutex = 1
        
        ;------------------------------------------------------------------------------------------
        ; Warn other components that the alarm checker should not be run right now
        ;------------------------------------------------------------------------------------------
        
        Program\DontCheck = 1
        
        ;------------------------------------------------------------------------------------------
        ; Add the various keyboard shortcuts
        ;------------------------------------------------------------------------------------------
        
        AddKeyboardShortcut(#Window_AppointmentArchive, #PB_Shortcut_Escape, #Shortcut_AppointmentArchive_Escape)
        
        AddKeyboardShortcut(#Window_AppointmentArchive, #PB_Shortcut_Return, #Shortcut_AppointmentArchive_Enter)
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
        AddHoverGadget(GadgetID(#Gadget_AppointmentArchive_Restore))
        
        AddHoverGadget(GadgetID(#Gadget_AppointmentArchive_Delete))
        
        AddHoverGadget(GadgetID(#Gadget_AppointmentArchive_Find))
        
        AddHoverGadget(GadgetID(#Gadget_AppointmentArchive_Help))
        
        AddHoverGadget(GadgetID(#Gadget_AppointmentArchive_Print))
        
        AddHoverGadget(GadgetID(#Gadget_AppointmentArchive_Exit))
        
        ;------------------------------------------------------------------------------------------
        ; Use the common message as a window identifier
        ;------------------------------------------------------------------------------------------
        
        Message.s = "List Of All Archived Appointments"
        
        ;------------------------------------------------------------------------------------------
        ; Use the common message as a window identifier
        ;------------------------------------------------------------------------------------------
        
        Program\LastWindow = Message.s
        
        ;------------------------------------------------------------------------------------------
        ; Set the window title with the common message and next record number
        ;------------------------------------------------------------------------------------------
        
        SetWindowTitle(#Window_AppointmentArchive, Message.s)
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
        ItemCounter.i = 0
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
        With Appointment
          
          ;----------------------------------------------------------------------------------------
          ; 
          ;----------------------------------------------------------------------------------------
          
          QueryString.s = "SELECT * FROM Archive"
          
          ;----------------------------------------------------------------------------------------
          ; 
          ;----------------------------------------------------------------------------------------
          
          If DatabaseQuery(Program\DatabaseHandle,  QueryString.s)
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            While NextDatabaseRow(Program\DatabaseHandle)
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              \appName        = KillQuote(GetDatabaseString(Program\DatabaseHandle,   0))
              
              \appDate        =    IsoDate(GetDatabaseString(Program\DatabaseHandle,  1), "NormalDate")
              
              \appTime        =            GetDatabaseString(Program\DatabaseHandle,  2) 
              
              \appAlarm       =    IsoDate(GetDatabaseString(Program\DatabaseHandle,  3), "NormalDate")
              
              \appRepeat      =            GetDatabaseString(Program\DatabaseHandle,  4) 
              
              \appProtect     =            GetDatabaseString(Program\DatabaseHandle,  5) 
              
              \appCategory    =  KillQuote(GetDatabaseString(Program\DatabaseHandle,  6))
              
              \appStatus      =  KillQuote(GetDatabaseString(Program\DatabaseHandle,  7))
              
              \appComment     =  KillQuote(GetDatabaseString(Program\DatabaseHandle,  8))
              
              \appArchived    =  KillQuote(GetDatabaseString(Program\DatabaseHandle,  9))
              
              \appEmailed     =  KillQuote(GetDatabaseString(Program\DatabaseHandle, 10))
              
              \appSound       =  KillQuote(GetDatabaseString(Program\DatabaseHandle, 11))
              
              \appDeleted     =            GetDatabaseString(Program\DatabaseHandle, 12) 
              
              \appRecord      =            GetDatabaseString(Program\DatabaseHandle, 13) 
              
              ;------------------------------------------------------------------------------------
              ; Now, off to the display routine. It must set icons, data and nicely formatted dates
              ;------------------------------------------------------------------------------------
              
              DisplayArchiveString(ItemCounter.i, "AddMode")
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              ItemCounter.i + 1
              
              ;------------------------------------------------------------------------------------
              ; Tell the user what is going on in the status bar 
              ;------------------------------------------------------------------------------------
              
              SetInfoBarArea("Headings", "Info",  "Showing: " + KillQuote(\appName))
              
              SetInfoBarArea("Records",  "",        Str(ItemCounter.i))
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
              ClearStructure(@Appointment, AppointmentData)
              
              ;------------------------------------------------------------------------------------
              ; 
              ;------------------------------------------------------------------------------------
              
            Wend
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            FinishDatabaseQuery(Program\DatabaseHandle)
            
            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
            If CountGadgetItems(#Gadget_AppointmentArchive_Appointments) <> 0
              
              ;------------------------------------------------------------------------------------------------
              ; Show the appointment names for the selected option set of dates by triggering a change event on;
              ; it.
              ;------------------------------------------------------------------------------------------------
              
              SetActiveGadget(#Gadget_AppointmentArchive_Appointments)

              SetGadgetState(#Gadget_AppointmentArchive_Appointments, 0)
              
              PostEvent(#PB_Event_Gadget, #Window_AppointmentArchive, #Gadget_AppointmentArchive_Appointments, #PB_EventType_Change)
              
            EndIf
            
            ;------------------------------------------------------------------------------------------------
            ; Limit the number of search box characters and set the cue banner text. These variables are set
            ; in the AppointmentMuncher_Myconstants file.
            ;------------------------------------------------------------------------------------------------
            
            SendMessage_(GadgetID(#Gadget_AppointmentArchive_Search), #EM_SETLIMITTEXT, 67, 0)
            
            SendMessage_(GadgetID(#Gadget_AppointmentArchive_Search), #EM_SETCUEBANNER,  1,  Program\SearchCueText)
            
            ;--------------------------------------------------------------------------------------
            ; Set focus on the search bar
            ;--------------------------------------------------------------------------------------
            
            SetActiveGadget(#Gadget_AppointmentArchive_Search)

            ;--------------------------------------------------------------------------------------
            ; 
            ;--------------------------------------------------------------------------------------
            
          Else
            
            SetInfoBarArea("Headings", "Error", #InfoStringQueryFailed + DatabaseError(), "ShowArchivedAppointments")
            
          EndIf
          
          ;----------------------------------------------------------------------------------------
          ; 
          ;----------------------------------------------------------------------------------------
          
        EndWith
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
        Program\DontCheck = 0
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
        SetInfoBarArea("Headings",  "Info",  Message.s, "ShowArchivedAppointments")
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
      Else
        
        SetInfoBarArea("Headings",  "Error",  #InfoStringCannotOpen, "ShowArchivedAppointments")
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings",  "Warn",  #InfoStringWindowOpen, "ShowArchivedAppointments")
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings",  "Warn",  #InfoStringAlarmRunning, "ShowArchivedAppointments")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure


; IDE Options = PureBasic 5.23 LTS (Windows - x86)
; CursorPosition = 30
; FirstLine = 6
; Folding = -
; EnableXP