﻿;========================================================================================================================================
; Find appointments with more advanced SQL queries
;========================================================================================================================================

Procedure FindAppointments()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if the alarm checker is running first
  ;------------------------------------------------------------------------------------------------
  
  If Program\DontCheck <> 1
    
    ;----------------------------------------------------------------------------------------------
    ; Check if a previous window is open
    ;----------------------------------------------------------------------------------------------
    
    If Program\WindowMutex <> 1
      
      ;--------------------------------------------------------------------------------------------
      ; Try to open the data window
      ;--------------------------------------------------------------------------------------------
      
      If Window_AppointmentFind()
        
        ;------------------------------------------------------------------------------------------
        ; Prevent user input on the main window
        ;------------------------------------------------------------------------------------------
        
        DisableWindow(#Window_AppointmentMuncher, #True)
        
        ;------------------------------------------------------------------------------------------
        ; Warn other components a window is open and not to attempt to open another
        ;------------------------------------------------------------------------------------------
        
        Program\WindowMutex = 1
        
        ;------------------------------------------------------------------------------------------
        ; Warn other components that the alarm checker should not be run right now
        ;------------------------------------------------------------------------------------------
        
        Program\DontCheck = 1
        
        ;------------------------------------------------------------------------------------------
        ; Add the various keyboard shortcuts
        ;------------------------------------------------------------------------------------------
        
        AddKeyboardShortcut(#Window_AppointmentFind, #PB_Shortcut_Escape, #Shortcut_AppointmentFind_Escape)
        
        AddKeyboardShortcut(#Window_AppointmentFind, #PB_Shortcut_Return, #Shortcut_AppointmentFind_Enter)
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
        AddHoverGadget(GadgetID(#Gadget_AppointmentFind_Find))
      
        AddHoverGadget(GadgetID(#Gadget_AppointmentFind_Exit))
        
        ;------------------------------------------------------------------------------------------
        ; Remove theme support from the comment box or it retains a border even when API removed
        ;------------------------------------------------------------------------------------------
        
        ; SetWindowTheme_(GadgetID(#Gadget_AppointmentFind_sQueryReturnLimit),   @null.w, @null.w)
        
        ;------------------------------------------------------------------------------------------
        ; Set the common window and statusbar message
        ;------------------------------------------------------------------------------------------
        
        Message.s = "Find Appointments"
      
        ;------------------------------------------------------------------------------------------
        ; Use the common message as a window identifier
        ;------------------------------------------------------------------------------------------
        
        Program\LastWindow = Message.s
        
        ;------------------------------------------------------------------------------------------
        ; Add the search type operators
        ;------------------------------------------------------------------------------------------
        
        Restore SearchTypes
        
        While TempString.s <> "_EndSearchTypes_"
          
          Read.s TempString.s
          
          If TempString.s <> "_EndSearchTypes_"
            
            AddGadgetItem(#Gadget_AppointmentFind_FindType, -1, TempString.s, ImageID(#SearchType))
            
          EndIf
          
        Wend
        
        TempString.s = "<>"
        
        SetGadgetState(#Gadget_AppointmentFind_FindType, 0)
        
        ;------------------------------------------------------------------------------------------
        ; Add the search field operators
        ;------------------------------------------------------------------------------------------
        
        Restore SearchFields
        
        While TempString.s <> "_EndSearchFields_"
          
          Read.s TempString.s
          
          If TempString.s <> "_EndSearchFields_"
            
            AddGadgetItem(#Gadget_AppointmentFind_Searchfield, -1, TempString.s, ImageID(#SearchField))
            
          EndIf
          
        Wend
        
        TempString.s = "<>"
        
        SetGadgetState(#Gadget_AppointmentFind_Searchfield, 0)
        
        ;------------------------------------------------------------------------------------------
        ; Add the search field operators
        ;------------------------------------------------------------------------------------------
        
        Restore SearchFields
        
        While TempString.s <> "_EndSearchFields_"
          
          Read.s TempString.s
          
          If TempString.s <> "_EndSearchFields_"
            
            AddGadgetItem(#Gadget_AppointmentFind_SortField, -1, TempString.s, ImageID(#SearchField))
            
          EndIf
          
        Wend
        
        TempString.s = "<>"
        
        SetGadgetState(#Gadget_AppointmentFind_SortField, 0)
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------

        SetGadgetState(#Gadget_AppointmentFind_oSortAcending,        1)
        
        SetGadgetState(#Gadget_AppointmentFind_cbQueryReturnLimit,   1)
        
        SetGadgetState(#Gadget_AppointmentFind_sQueryReturnLimit,   10)
        
        SetGadgetText(#Gadget_AppointmentFind_sQueryReturnLimit,   "10")
        
        ;------------------------------------------------------------------------------------------
        ; Set the window title with the common message and next record number
        ;------------------------------------------------------------------------------------------
        
        SetWindowTitle(#Window_AppointmentFind, Message.s + " (Advanced search)")
        
        ;------------------------------------------------------------------------------------------
        ; Set the current operation details on the the main window status bar
        ;------------------------------------------------------------------------------------------
        
        SetInfoBarArea("Headings",  "Info",  Message.s + " (Advanced search)")
        
        ;------------------------------------------------------------------------------------------
        ; Limit the number of search box characters and set the cue banner text
        ;------------------------------------------------------------------------------------------
        
        SendMessage_(GadgetID(#Gadget_AppointmentFind_Searchtext), #EM_SETLIMITTEXT, 67, 0)
        
        SendMessage_(GadgetID(#Gadget_AppointmentFind_Searchtext), #EM_SETCUEBANNER,  1,  Program\SearchCueText)

        ;------------------------------------------------------------------------------------------
        ; Set focus on the appointment name field
        ;------------------------------------------------------------------------------------------
        
        SetActiveGadget(#Gadget_AppointmentFind_Searchtext)
      
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
      Else
        
        SetInfoBarArea("Headings",  "Error",  #InfoStringCannotOpen, "FindAppointments")
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings",  "Warn",  #InfoStringWindowOpen)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
      
    SetInfoBarArea("Headings",  "Warn",  #InfoStringAlarmRunning)
      
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure

; IDE Options = PureBasic 5.22 LTS (Windows - x86)
; CursorPosition = 186
; FirstLine = 180
; Folding = -
; EnableXP