﻿;==========================================================================================================================================================
; Show a list of all the keyboard shortcuts
;==========================================================================================================================================================

Procedure KeysAppointments()
  
  ;------------------------------------------------------------------------------------------------
  ; Check if the alarm checker is running first
  ;------------------------------------------------------------------------------------------------
  
  If Program\DontCheck <> 1
    
    ;----------------------------------------------------------------------------------------------
    ; Check if a previous window is open
    ;----------------------------------------------------------------------------------------------
    
    If Program\WindowMutex <> 1
      
      ;--------------------------------------------------------------------------------------------
      ; Try to open the data window
      ;--------------------------------------------------------------------------------------------
      
      If Window_AppointmentKeys()
        
        ;------------------------------------------------------------------------------------------
        ; Prevent user input on the main window
        ;------------------------------------------------------------------------------------------
        
        DisableWindow(#Window_AppointmentMuncher, #True)
        
        ;------------------------------------------------------------------------------------------
        ; Warn other components a window is open and not to attempt to open another
        ;------------------------------------------------------------------------------------------
        
        Program\WindowMutex = 1
        
        ;------------------------------------------------------------------------------------------
        ; Warn other components that the alarm checker should not be run right now
        ;------------------------------------------------------------------------------------------
        
        Program\DontCheck = 1
        
        ;------------------------------------------------------------------------------------------
        ; Add the various keyboard shortcuts
        ;------------------------------------------------------------------------------------------
        
        AddKeyboardShortcut(#Window_AppointmentKeys, #PB_Shortcut_Escape, #Shortcut_AppointmentKeys_Escape)
        
        ;------------------------------------------------------------------------------------------
        ; Set the common window and statusbar message
        ;------------------------------------------------------------------------------------------
        
        Message.s = "Show keyboard shortcuts"
        
        ;------------------------------------------------------------------------------------------
        ; Use the common message as a window identifier
        ;------------------------------------------------------------------------------------------
        
        Program\LastWindow = Message.s
        
        ;------------------------------------------------------------------------------------------
        ; Set the window title with the common message and next record number
        ;------------------------------------------------------------------------------------------
        
        SetWindowTitle(#Window_AppointmentKeys, Message.s)
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Add)           + Chr(10) + #BalloonTextAddAppointment,       ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Archive)       + Chr(10) + #BalloonTextArchiveAppointment,   ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Copy)          + Chr(10) + #BalloonTextCopyAppointment,      ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Delete)        + Chr(10) + #BalloonTextDeleteAppointment,    ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Edit)          + Chr(10) + #BalloonTextEditAppointment,      ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Export)        + Chr(10) + #BalloonTextExportAppointments,   ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Find)          + Chr(10) + #BalloonTextFindAppointment,      ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Help)          + Chr(10) + #BalloonTextHelpAppointment,      ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Import)        + Chr(10) + #BalloonTextImportAppointments,   ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Print)         + Chr(10) + #BalloonTextPrintAppointment,     ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Undelete)      + Chr(10) + #BalloonTextUndeleteAppointment,  ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Exit)          + Chr(10) + #BalloonTextExitAppointment,      ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_About)         + Chr(10) + #BalloonTextAboutAppointments,    ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Shortcuts)     + Chr(10) + #BalloonTextKeyboardShortcuts,    ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Tooltips)      + Chr(10) + #BalloonTextToggleTooltips,       ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Stickywindow)  + Chr(10) + #BalloonTextToggleStickywindow,   ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Titleclock)    + Chr(10) + #BalloonTextToggleTitleClock,     ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Screensnap)    + Chr(10) + #BalloonTextToggleScreenSnap,     ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Cleandatabase) + Chr(10) + #BalloonTextCleanDatabase,        ImageID(#Shortcuts))
        
        AddGadgetItem(#Gadget_AppointmentKeys_Keylist, -1, GetShortCutText(#ShortcutKeys_Setupprogram)  + Chr(10) + #BalloonTextSetupprogram,         ImageID(#Shortcuts))
        
        ;------------------------------------------------------------------------------------------
        ; Set the current operation details on the the main window status bar
        ;------------------------------------------------------------------------------------------
        
        SetInfoBarArea("Headings",  "Info",  Message.s)
        
        ;------------------------------------------------------------------------------------------
        ; Set focus on the appointment name field
        ;------------------------------------------------------------------------------------------
        
        SetActiveGadget(#Gadget_AppointmentKeys_Keylist)
        
        ;------------------------------------------------------------------------------------------
        ; 
        ;------------------------------------------------------------------------------------------
        
      Else
        
        SetInfoBarArea("Headings",  "Error",  #InfoStringCannotOpen, "KeysAppointments")
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Else
      
      SetInfoBarArea("Headings",  "Warn",  #InfoStringWindowOpen)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings",  "Warn",  #InfoStringAlarmRunning)
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure



; IDE Options = PureBasic 5.23 LTS (Windows - x86)
; CursorPosition = 19
; FirstLine = 78
; Folding = -
; EnableXP