﻿;==========================================================================================================================================================
; Export appointment data to a standard XML file
;==========================================================================================================================================================

Procedure ExportAppointments()
  
  ;------------------------------------------------------------------------------------------------
  ; Process the current table name
  ;------------------------------------------------------------------------------------------------
  
  If DatabaseQuery(Program\DatabaseHandle,  "SELECT * FROM Appointments")
    
    ;----------------------------------------------------------------------------------------------
    ; Process the next returned row
    ;----------------------------------------------------------------------------------------------
    
    While NextDatabaseRow(Program\DatabaseHandle)
      
      ;--------------------------------------------------------------------------------------------
      ; Have we created this XML tree already?
      ;--------------------------------------------------------------------------------------------
      
      If *XmlTree = 0
        
        *XmlTree = CreateXML(#PB_Any)                                                       ; Creates a new empty XML tree identified by the #XML number
        
        *RootXmlNode = CreateXMLNode(RootXMLNode(*XmlTree))                                 ; Creates a new XML node and inserts it into the given parent node. 
        
        SetXMLNodeName(*RootXmlNode, "AppointmentMuncher")                                  ; Changes the tagname of the given XML node (root in this case)
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; Creates a new XML node and inserts it into main XML node of the tree.
      ;--------------------------------------------------------------------------------------------
      
      *RowNode = CreateXMLNode(MainXMLNode(*XmlTree))
      
      ;--------------------------------------------------------------------------------------------
      ; If the main node was created, dump all the columns using the column names as node names
      ;--------------------------------------------------------------------------------------------
      
      If *RowNode
        
        ;------------------------------------------------------------------------------------------
        ; Changes the tagname of the given XML node (main node in this case)
        ;------------------------------------------------------------------------------------------
        
        SetXMLNodeName(*RowNode, "AppointmentItem")
        
        ;------------------------------------------------------------------------------------------
        ; Get the column names and write them first
        ;------------------------------------------------------------------------------------------
        
        NumberOfColumns.i = DatabaseColumns(Program\DatabaseHandle)
        
        ;------------------------------------------------------------------------------------------
        ; Iterate through the columns
        ;------------------------------------------------------------------------------------------
        
        For ColumnNamesLoop.i = 0 To NumberOfColumns.i -1
          
          CurrentColumn.s = DatabaseColumnName(Program\DatabaseHandle, ColumnNamesLoop.i)
          
          *ColumnNode = CreateXMLNode(*RowNode)                                             ; Creates a new XML node and inserts it into main XML node of the tree.
          
          SetXMLNodeName(*ColumnNode, CurrentColumn.s)                                      ; Set the node name to be the current column name
          
          SetXMLNodeText(*ColumnNode, TextToXml(GetDatabaseString(Program\DatabaseHandle,  ColumnNamesLoop.i)))
          
        Next                                                                                ; Next column
        
        ;------------------------------------------------------------------------------------------
        ; Main node wasn't created, exit out of this procedure
        ;------------------------------------------------------------------------------------------
        
      Else
        
        SetInfoBarArea("Headings",  "Error",  #InfoStringXmlCreateError, "ExportAppointments")
        
        ProcedureReturn
        
      EndIf
      
      ;--------------------------------------------------------------------------------------------
      ; 
      ;--------------------------------------------------------------------------------------------
      
    Wend
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    FinishDatabaseQuery(Program\DatabaseHandle)
    
    ;----------------------------------------------------------------------------------------------
    ; 
    ;----------------------------------------------------------------------------------------------
    
    If *XmlTree
      
      FormatXML(*XmlTree, #PB_XML_ReFormat)
      
      SaveXML(*XmlTree, Program\TemporaryDirectory + #Program + "_Export.xml")
      
      FreeXML(*XmlTree)
      
      SetInfoBarArea("Headings",  "Info",  #InfoStringXmlDataSaved)
      
    EndIf
    
    ;----------------------------------------------------------------------------------------------
    ; The database query has failed for some reason
    ;----------------------------------------------------------------------------------------------
    
  Else
    
    SetInfoBarArea("Headings",  "Error",  #InfoStringQueryFailed, "ExportAppointments")
    
  EndIf
  
  ;------------------------------------------------------------------------------------------------
  ; 
  ;------------------------------------------------------------------------------------------------
  
EndProcedure


; IDE Options = PureBasic 5.22 LTS (Windows - x86)
; Folding = -
; EnableXP